==> distfun-0.3-1-src.zip: distfun/sci_gateway/cgrand/sci_distfun_grandunf.c <==

/*
* Copyright (C)  2012 - Michael Baudin
* Copyright (C)  2001 - Bruno Pincon
* Copyright (C) ENPC
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

/*------------------------------------------------------------------------
*    Interface for grand
*    jpc@cermics.enpc.fr
*    stuff to deal with several generators added
*         by Bruno Pincon (12/11/2001)
*
--------------------------------------------------------------------------*/
#include <string.h>
#include <math.h>

// From Distfun:
#include "gwsupport.h"
#include "genrand.h"
#include "gw_distfungrand.h"
#include "gw_distfungrand_support.h" 

// From Scilab:
#include "api_scilab.h"
#include "Scierror.h"
#include "localization.h"
#include "stack-c.h"

/**************************************************
Y=distfun_grandunf(m,n,a,b)

generates random reals uniformly distributed in [a, b).
***********************************************************************/

int sci_distfun_grandunf(char *fname,unsigned long fname_len)
{
	int ma, na;
	int mb, nb;
	int rRows,rCols;
	int i;
	int readFlag;
	
	double * pa = NULL;
	double * pb = NULL;

	CheckRhs(4,4);
	CheckLhs(1,1);

	// Get Arg #1 = M, Arg #2 = N
	readFlag = distfun_GetMN ( fname , &rRows , &rCols );
	if ( readFlag == 0)
	{ 
		return 0;
	}
    // Arg #3 : a
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 3, &pa, &ma, &na);
	if ( readFlag == 0)
	{ 
		return 0;
	}
    // Arg #4 : b
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 4, &pb, &mb, &nb);
	if ( readFlag == 0)
	{ 
		return 0;
	}
	// Check that size(a)==size(b)
	readFlag = gwsupport_CheckSize ( fname, 4, ma, na, mb, nb);
	if ( readFlag == 0)
	{ 
		return 0;
	}
	// Check that a<=b
	for ( i=0 ; i < ma*na ; i++)
	{
		if ( *(pa+i) > *(pb+i) )
		{
			Scierror(999,_("%s: Wrong value for input argument #%d: ""%s"" expected .\n"),fname,3,"a<=b");
			return 0;
		}
	}
    // Compute the result (if necessary, expand the arguments a and b)
	readFlag = distfun_computeRandgenAB (fname, ma, na, pa, mb, nb, pb, rRows, rCols, C2F(genunf) );
	if ( readFlag == 0)
	{ 
		return 0;
	}
	LhsVar(1) = Rhs+1;
	return 0;
}

==> distfun-0.5-1-src.zip: distfun/sci_gateway/cgrand/sci_distfun_grandunf.c <==

/*
* Copyright (C)  2012 - Michael Baudin
* Copyright (C)  2001 - Bruno Pincon
* Copyright (C) ENPC
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

/*------------------------------------------------------------------------
*    Interface for grand
*    jpc@cermics.enpc.fr
*    stuff to deal with several generators added
*         by Bruno Pincon (12/11/2001)
*
--------------------------------------------------------------------------*/
#include <string.h>
#include <math.h>

// From Distfun:
#include "gwsupport.h"
#include "genrand.h"
#include "gw_distfungrand.h"
#include "gw_distfungrand_support.h" 

// From Scilab:
#include "api_scilab.h"
#include "Scierror.h"
#include "localization.h"
#include "stack-c.h"

/**************************************************
Y=distfun_grandunf(m,n,a,b)

generates random reals uniformly distributed in [a, b).
***********************************************************************/

int sci_distfun_grandunf(char *fname,unsigned long fname_len)
{
	int ma, na;
	int mb, nb;
	int rRows,rCols;
	int i;
	int readFlag;
	
	double * pa = NULL;
	double * pb = NULL;

	CheckInputArgument(pvApiCtx,4,4);
	CheckOutputArgument(pvApiCtx,1,1);

	// Get Arg #1 = M, Arg #2 = N
	readFlag = distfun_GetMN ( fname , &rRows , &rCols );
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
    // Arg #3 : a
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 3, &pa, &ma, &na);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
    // Arg #4 : b
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 4, &pb, &mb, &nb);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
	// Check that size(a)==size(b)
	readFlag = gwsupport_CheckSize ( fname, 4, ma, na, mb, nb);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
	// Check that a<=b
	for ( i=0 ; i < ma*na ; i++)
	{
		if ( *(pa+i) > *(pb+i) )
		{
			Scierror(999,_("%s: Wrong value for input argument #%d: ""%s"" expected .\n"),fname,3,"a<=b");
			return 0;
		}
	}
    // Compute the result (if necessary, expand the arguments a and b)
	readFlag = distfun_computeRandgenAB (fname, ma, na, pa, mb, nb, pb, rRows, rCols, genrand_genunf );
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
	LhsVar(1) = Rhs+1;
	return 0;
}
